@@ -48,7 +48,7 @@
 
 #include <sys/socket.h> /* for sa_family_t */
 #include <nuttx/can.h>
-#include <nuttx/can/error.h>
+#include "error.h"
 #include <netpacket/can.h>
 
 #include "lib.h"
