@@ -1,35 +1,20 @@
 /****************************************************************************
- * examples/adc/powerled_main.c
+ * apps/examples/powerled/powerled_main.c
  *
- *   Copyright (C) 2017 Gregory Nutt. All rights reserved.
- *   Author: Mateusz Szafoni <raiden00@railab.me>
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.  The
+ * ASF licenses this file to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance with the
+ * License.  You may obtain a copy of the License at
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- * 3. Neither the name NuttX nor the names of its contributors may be
- *    used to endorse or promote products derived from this software
- *    without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
- * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
- * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
- * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
- * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
- * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
- * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+ * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
+ * License for the specific language governing permissions and limitations
+ * under the License.
  *
  ****************************************************************************/
 
@@ -207,7 +192,7 @@ static void parse_args(FAR struct args_s *args, int argc, FAR char **argv)
   int i_value;
   float f_value;
 
-  for (index = 1; index < argc;)
+  for (index = 1; index < argc; )
     {
       ptr = argv[index];
       if (ptr[0] != '-')
@@ -476,7 +461,8 @@ int main(int argc, char *argv[])
 
   /* Set LED current limit */
 
-  powerled_limits.current = (((float)CONFIG_EXAMPLES_POWERLED_CURRENT_LIMIT)/1000.0);
+  powerled_limits.current =
+          (((float)CONFIG_EXAMPLES_POWERLED_CURRENT_LIMIT) / 1000.0);
 
   printf("\nStart powerled_main application!\n");
 
@@ -485,7 +471,8 @@ int main(int argc, char *argv[])
   fd = open(CONFIG_EXAMPLES_POWERLED_DEVPATH, 0);
   if (fd <= 0)
     {
-      printf("powerled_main: open %s failed %d\n", CONFIG_EXAMPLES_POWERLED_DEVPATH, errno);
+      printf("powerled_main: open %s failed %d\n",
+             CONFIG_EXAMPLES_POWERLED_DEVPATH, errno);
       goto errout;
     }
 
@@ -520,7 +507,8 @@ int main(int argc, char *argv[])
 
                       /* Set Powerled continuous mode */
 
-                      ret = ioctl(fd, PWRIOC_SET_MODE, (unsigned long)powerled_mode);
+                      ret = ioctl(fd, PWRIOC_SET_MODE,
+                                 (unsigned long)powerled_mode);
                       if (ret < 0)
                         {
                           printf("failed to set powerled mode %d \n", ret);
@@ -533,7 +521,8 @@ int main(int argc, char *argv[])
 
                   /* Set Powerled parameters */
 
-                  ret = ioctl(fd, PWRIOC_SET_PARAMS, (unsigned long)&powerled_params);
+                  ret = ioctl(fd, PWRIOC_SET_PARAMS,
+                             (unsigned long)&powerled_params);
                   if (ret < 0)
                     {
                       printf("failed to set params %d \n", ret);
@@ -564,7 +553,6 @@ int main(int argc, char *argv[])
                   sleep(1);
                 }
 
-
               if (demo == POWERLED_OPMODE_FLASH)
                 {
                   /* Flash mode demo */
@@ -581,13 +569,15 @@ int main(int argc, char *argv[])
 
                       /* Set Powerled flash mode */
 
-                      ret = ioctl(fd, PWRIOC_SET_MODE, (unsigned long)powerled_mode);
+                      ret = ioctl(fd, PWRIOC_SET_MODE,
+                                 (unsigned long)powerled_mode);
                       if (ret < 0)
                         {
                           printf("failed to set powerled mode %d \n", ret);
                         }
 
-                      printf("Brightness is %.2f\n", powerled_params.brightness);
+                      printf("Brightness is %.2f\n",
+                             powerled_params.brightness);
                       printf("Duty is %.2f\n", powerled_params.duty);
 
                       config = false;
@@ -597,7 +587,8 @@ int main(int argc, char *argv[])
 
                   /* Set Powerled parameters */
 
-                  ret = ioctl(fd, PWRIOC_SET_PARAMS, (unsigned long)&powerled_params);
+                  ret = ioctl(fd, PWRIOC_SET_PARAMS,
+                             (unsigned long)&powerled_params);
                   if (ret < 0)
                     {
                       printf("failed to set params %d \n", ret);
@@ -643,7 +634,8 @@ int main(int argc, char *argv[])
 
                   /* Set Powerled continuous mode */
 
-                  ret = ioctl(fd, PWRIOC_SET_MODE, (unsigned long)powerled_mode);
+                  ret = ioctl(fd, PWRIOC_SET_MODE,
+                             (unsigned long)powerled_mode);
                   if (ret < 0)
                     {
                       printf("failed to set powerled mode %d \n", ret);
@@ -655,7 +647,8 @@ int main(int argc, char *argv[])
 
                   /* Set Powerled parameters */
 
-                  ret = ioctl(fd, PWRIOC_SET_PARAMS, (unsigned long)&powerled_params);
+                  ret = ioctl(fd, PWRIOC_SET_PARAMS,
+                             (unsigned long)&powerled_params);
                   if (ret < 0)
                     {
                       printf("failed to set params %d \n", ret);
@@ -687,7 +680,8 @@ int main(int argc, char *argv[])
 
                   /* Set Powerled flash mode */
 
-                  ret = ioctl(fd, PWRIOC_SET_MODE, (unsigned long)powerled_mode);
+                  ret = ioctl(fd, PWRIOC_SET_MODE,
+                             (unsigned long)powerled_mode);
                   if (ret < 0)
                     {
                       printf("failed to set powerled mode %d \n", ret);
@@ -699,7 +693,8 @@ int main(int argc, char *argv[])
 
                   /* Set Powerled parameters */
 
-                  ret = ioctl(fd, PWRIOC_SET_PARAMS, (unsigned long)&powerled_params);
+                  ret = ioctl(fd, PWRIOC_SET_PARAMS,
+                             (unsigned long)&powerled_params);
                   if (ret < 0)
                     {
                       printf("failed to set params %d \n", ret);
