@@ -68,7 +68,10 @@
  * Private Data
  ****************************************************************************/
 
-static const uint8_t tevents[] = { POLLIN, POLLOUT, POLLOUT|POLLIN, 0};
+static const uint8_t tevents[] =
+{
+  POLLIN, POLLOUT, POLLOUT | POLLIN, 0
+};
 static bool started;
 static int sd;
 
@@ -97,7 +100,7 @@ static int sd;
  *
  ****************************************************************************/
 
-static void Unreachable(struct usrsocktest_daemon_conf_s *dconf)
+static void unreachable(struct usrsocktest_daemon_conf_s *dconf)
 {
   ssize_t ret;
   struct sockaddr_in addr;
@@ -215,11 +218,10 @@ static void Unreachable(struct usrsocktest_daemon_conf_s *dconf)
   TEST_ASSERT_EQUAL(-ENODEV, usrsocktest_daemon_get_num_connected_sockets());
   TEST_ASSERT_EQUAL(0, usrsocktest_endp_malloc_cnt);
   TEST_ASSERT_EQUAL(0, usrsocktest_dcmd_malloc_cnt);
-
 }
 
 /****************************************************************************
- * Name: Send
+ * Name: remote_disconnect_send
  *
  * Description:
  *   Send and disconnect
@@ -235,7 +237,7 @@ static void Unreachable(struct usrsocktest_daemon_conf_s *dconf)
  *
  ****************************************************************************/
 
-static void Send(struct usrsocktest_daemon_conf_s *dconf)
+static void remote_disconnect_send(struct usrsocktest_daemon_conf_s *dconf)
 {
   ssize_t ret;
   size_t datalen;
@@ -276,18 +278,22 @@ static void Send(struct usrsocktest_daemon_conf_s *dconf)
   TEST_ASSERT_EQUAL(1, usrsocktest_daemon_get_num_connected_sockets());
   TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_waiting_connect_sockets());
   TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_unreachable_sockets());
-  TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_remote_disconnected_sockets());
+  TEST_ASSERT_EQUAL(0,
+                  usrsocktest_daemon_get_num_remote_disconnected_sockets());
 
   /* Disconnect connections. */
 
   TEST_ASSERT_TRUE(usrsocktest_send_delayed_command('D', 0));
-  for (count = 0; usrsocktest_daemon_get_num_connected_sockets() > 0; count++)
+  for (count = 0; usrsocktest_daemon_get_num_connected_sockets() > 0;
+       count++)
     {
       TEST_ASSERT_TRUE(count <= 3);
       usleep(5 * 1000);
     }
+
   TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_connected_sockets());
-  TEST_ASSERT_EQUAL(1, usrsocktest_daemon_get_num_remote_disconnected_sockets());
+  TEST_ASSERT_EQUAL(1,
+                  usrsocktest_daemon_get_num_remote_disconnected_sockets());
 
   for (count = 0; count < 2; count++)
     {
@@ -299,7 +305,8 @@ static void Send(struct usrsocktest_daemon_conf_s *dconf)
       TEST_ASSERT_EQUAL(-1, ret);
       TEST_ASSERT_EQUAL(EPIPE, errno);
       TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_connected_sockets());
-      TEST_ASSERT_EQUAL(1, usrsocktest_daemon_get_num_remote_disconnected_sockets());
+      TEST_ASSERT_EQUAL(1,
+                  usrsocktest_daemon_get_num_remote_disconnected_sockets());
       TEST_ASSERT_EQUAL(1, usrsocktest_daemon_get_num_active_sockets());
       TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_send_bytes());
     }
@@ -322,7 +329,7 @@ static void Send(struct usrsocktest_daemon_conf_s *dconf)
 }
 
 /****************************************************************************
- * Name: Send2
+ * Name: remote_disconnect_send2
  *
  * Description:
  *   Send and disconnect
@@ -338,7 +345,7 @@ static void Send(struct usrsocktest_daemon_conf_s *dconf)
  *
  ****************************************************************************/
 
-static void Send2(struct usrsocktest_daemon_conf_s *dconf)
+static void remote_disconnect_send2(struct usrsocktest_daemon_conf_s *dconf)
 {
   ssize_t ret;
   size_t datalen;
@@ -366,7 +373,8 @@ static void Send2(struct usrsocktest_daemon_conf_s *dconf)
   TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_waiting_connect_sockets());
   TEST_ASSERT_EQUAL(1, usrsocktest_daemon_get_num_recv_empty_sockets());
   TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_unreachable_sockets());
-  TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_remote_disconnected_sockets());
+  TEST_ASSERT_EQUAL(0,
+                  usrsocktest_daemon_get_num_remote_disconnected_sockets());
 
   /* Try connect. */
 
@@ -379,7 +387,8 @@ static void Send2(struct usrsocktest_daemon_conf_s *dconf)
   TEST_ASSERT_EQUAL(1, usrsocktest_daemon_get_num_connected_sockets());
   TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_waiting_connect_sockets());
   TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_unreachable_sockets());
-  TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_remote_disconnected_sockets());
+  TEST_ASSERT_EQUAL(0,
+                  usrsocktest_daemon_get_num_remote_disconnected_sockets());
 
   /* Disconnect connections with delay. */
 
@@ -396,7 +405,8 @@ static void Send2(struct usrsocktest_daemon_conf_s *dconf)
       TEST_ASSERT_EQUAL(EPIPE, errno);
       TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_connected_sockets());
       TEST_ASSERT_EQUAL(1, usrsocktest_daemon_get_num_active_sockets());
-      TEST_ASSERT_EQUAL(1, usrsocktest_daemon_get_num_remote_disconnected_sockets());
+      TEST_ASSERT_EQUAL(1,
+                  usrsocktest_daemon_get_num_remote_disconnected_sockets());
       TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_send_bytes());
     }
 
@@ -418,7 +428,7 @@ static void Send2(struct usrsocktest_daemon_conf_s *dconf)
 }
 
 /****************************************************************************
- * Name: Receive
+ * Name: receive
  *
  * Description:
  *   Receive and disconnect
@@ -434,7 +444,7 @@ static void Send2(struct usrsocktest_daemon_conf_s *dconf)
  *
  ****************************************************************************/
 
-static void Receive(struct usrsocktest_daemon_conf_s *dconf)
+static void receive(struct usrsocktest_daemon_conf_s *dconf)
 {
   ssize_t ret;
   size_t datalen;
@@ -475,19 +485,23 @@ static void Receive(struct usrsocktest_daemon_conf_s *dconf)
   TEST_ASSERT_EQUAL(1, usrsocktest_daemon_get_num_connected_sockets());
   TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_waiting_connect_sockets());
   TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_unreachable_sockets());
-  TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_remote_disconnected_sockets());
+  TEST_ASSERT_EQUAL(0,
+                   usrsocktest_daemon_get_num_remote_disconnected_sockets());
   TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_recv_empty_sockets());
 
   /* Disconnect connections. */
 
   TEST_ASSERT_TRUE(usrsocktest_send_delayed_command('D', 0));
-  for (count = 0; usrsocktest_daemon_get_num_connected_sockets() > 0; count++)
+  for (count = 0; usrsocktest_daemon_get_num_connected_sockets() > 0;
+       count++)
     {
       TEST_ASSERT_TRUE(count <= 3);
       usleep(5 * 1000);
     }
+
   TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_connected_sockets());
-  TEST_ASSERT_EQUAL(1, usrsocktest_daemon_get_num_remote_disconnected_sockets());
+  TEST_ASSERT_EQUAL(1,
+                  usrsocktest_daemon_get_num_remote_disconnected_sockets());
   TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_recv_empty_sockets());
 
   for (count = 0; count < 2; count++)
@@ -499,7 +513,8 @@ static void Receive(struct usrsocktest_daemon_conf_s *dconf)
       ret = read(sd, data, datalen);
       TEST_ASSERT_EQUAL(0, ret);
       TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_connected_sockets());
-      TEST_ASSERT_EQUAL(1, usrsocktest_daemon_get_num_remote_disconnected_sockets());
+      TEST_ASSERT_EQUAL(1,
+                  usrsocktest_daemon_get_num_remote_disconnected_sockets());
       TEST_ASSERT_EQUAL(1, usrsocktest_daemon_get_num_active_sockets());
       TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_recv_bytes());
     }
@@ -522,7 +537,7 @@ static void Receive(struct usrsocktest_daemon_conf_s *dconf)
 }
 
 /****************************************************************************
- * Name: Receive2
+ * Name: receive2
  *
  * Description:
  *   Receive and disconnect
@@ -538,7 +553,7 @@ static void Receive(struct usrsocktest_daemon_conf_s *dconf)
  *
  ****************************************************************************/
 
-static void Receive2(struct usrsocktest_daemon_conf_s *dconf)
+static void receive2(struct usrsocktest_daemon_conf_s *dconf)
 {
   ssize_t ret;
   size_t datalen;
@@ -568,7 +583,8 @@ static void Receive2(struct usrsocktest_daemon_conf_s *dconf)
   TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_waiting_connect_sockets());
   TEST_ASSERT_EQUAL(1, usrsocktest_daemon_get_num_recv_empty_sockets());
   TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_unreachable_sockets());
-  TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_remote_disconnected_sockets());
+  TEST_ASSERT_EQUAL(0,
+                  usrsocktest_daemon_get_num_remote_disconnected_sockets());
 
   /* Try connect. */
 
@@ -581,7 +597,8 @@ static void Receive2(struct usrsocktest_daemon_conf_s *dconf)
   TEST_ASSERT_EQUAL(1, usrsocktest_daemon_get_num_connected_sockets());
   TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_waiting_connect_sockets());
   TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_unreachable_sockets());
-  TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_remote_disconnected_sockets());
+  TEST_ASSERT_EQUAL(0,
+                  usrsocktest_daemon_get_num_remote_disconnected_sockets());
 
   /* Disconnect connections with delay. */
 
@@ -596,7 +613,8 @@ static void Receive2(struct usrsocktest_daemon_conf_s *dconf)
       ret = read(sd, data, datalen);
       TEST_ASSERT_EQUAL(0, ret);
       TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_connected_sockets());
-      TEST_ASSERT_EQUAL(1, usrsocktest_daemon_get_num_remote_disconnected_sockets());
+      TEST_ASSERT_EQUAL(1,
+                  usrsocktest_daemon_get_num_remote_disconnected_sockets());
       TEST_ASSERT_EQUAL(1, usrsocktest_daemon_get_num_active_sockets());
       TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_recv_bytes());
     }
@@ -619,7 +637,7 @@ static void Receive2(struct usrsocktest_daemon_conf_s *dconf)
 }
 
 /****************************************************************************
- * Name: Poll
+ * Name: remote_disconnect_poll
  *
  * Description:
  *   Poll and disconnect
@@ -635,7 +653,7 @@ static void Receive2(struct usrsocktest_daemon_conf_s *dconf)
  *
  ****************************************************************************/
 
-static void Poll(struct usrsocktest_daemon_conf_s *dconf)
+static void remote_disconnect_poll(struct usrsocktest_daemon_conf_s *dconf)
 {
   ssize_t ret;
   struct sockaddr_in addr;
@@ -713,7 +731,8 @@ static void Poll(struct usrsocktest_daemon_conf_s *dconf)
   TEST_ASSERT_EQUAL(0, pfd.revents & POLLOUT);
   TEST_ASSERT_EQUAL(1, usrsocktest_daemon_get_num_active_sockets());
   TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_connected_sockets());
-  TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_remote_disconnected_sockets());
+  TEST_ASSERT_EQUAL(0,
+                  usrsocktest_daemon_get_num_remote_disconnected_sockets());
   TEST_ASSERT_EQUAL(1, usrsocktest_daemon_get_num_unreachable_sockets());
 
   /* Close socket */
@@ -734,7 +753,7 @@ static void Poll(struct usrsocktest_daemon_conf_s *dconf)
 }
 
 /****************************************************************************
- * Name: Poll2
+ * Name: remote_disconnect_poll2
  *
  * Description:
  *   Poll and disconnect
@@ -750,7 +769,7 @@ static void Poll(struct usrsocktest_daemon_conf_s *dconf)
  *
  ****************************************************************************/
 
-static void Poll2(struct usrsocktest_daemon_conf_s *dconf)
+static void remote_disconnect_poll2(struct usrsocktest_daemon_conf_s *dconf)
 {
   ssize_t ret;
   size_t datalen;
@@ -776,7 +795,8 @@ static void Poll2(struct usrsocktest_daemon_conf_s *dconf)
 
   do
     {
-      TEST_ASSERT_TRUE(*events == POLLIN || *events == POLLOUT || *events == (POLLOUT|POLLIN));
+      TEST_ASSERT_TRUE(*events == POLLIN || *events == POLLOUT ||
+                       *events == (POLLOUT | POLLIN));
 
       /* Open socket */
 
@@ -784,7 +804,8 @@ static void Poll2(struct usrsocktest_daemon_conf_s *dconf)
       TEST_ASSERT_TRUE(sd >= 0);
       TEST_ASSERT_EQUAL(1, usrsocktest_daemon_get_num_active_sockets());
       TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_connected_sockets());
-      TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_waiting_connect_sockets());
+      TEST_ASSERT_EQUAL(0,
+                    usrsocktest_daemon_get_num_waiting_connect_sockets());
 
       /* Make socket non-blocking */
 
@@ -821,29 +842,37 @@ static void Poll2(struct usrsocktest_daemon_conf_s *dconf)
         {
           TEST_ASSERT_EQUAL(0, ret);
           TEST_ASSERT_EQUAL(1, usrsocktest_daemon_get_num_active_sockets());
-          TEST_ASSERT_EQUAL(1, usrsocktest_daemon_get_num_connected_sockets());
-          TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_waiting_connect_sockets());
-          TEST_ASSERT_EQUAL(1, usrsocktest_daemon_get_num_recv_empty_sockets());
+          TEST_ASSERT_EQUAL(1,
+                            usrsocktest_daemon_get_num_connected_sockets());
+          TEST_ASSERT_EQUAL(0,
+                      usrsocktest_daemon_get_num_waiting_connect_sockets());
+          TEST_ASSERT_EQUAL(1,
+                           usrsocktest_daemon_get_num_recv_empty_sockets());
         }
       else
         {
           TEST_ASSERT_EQUAL(-1, ret);
           TEST_ASSERT_EQUAL(EINPROGRESS, errno);
           TEST_ASSERT_EQUAL(1, usrsocktest_daemon_get_num_active_sockets());
-          TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_connected_sockets());
+          TEST_ASSERT_EQUAL(0,
+                            usrsocktest_daemon_get_num_connected_sockets());
 
-          for (count = 0; usrsocktest_daemon_get_num_connected_sockets() != 1; count++)
+          for (count = 0;
+               usrsocktest_daemon_get_num_connected_sockets() != 1; count++)
             {
               TEST_ASSERT_TRUE(count <= 3);
               usleep(25 * 1000);
             }
 
-          ret = connect(sd, (FAR const struct sockaddr *)&addr, sizeof(addr));
+          ret = connect(sd, (FAR const struct sockaddr *)&addr,
+                        sizeof(addr));
           TEST_ASSERT_EQUAL(-1, ret);
           TEST_ASSERT_EQUAL(EISCONN, errno);
           TEST_ASSERT_EQUAL(1, usrsocktest_daemon_get_num_active_sockets());
-          TEST_ASSERT_EQUAL(1, usrsocktest_daemon_get_num_connected_sockets());
-          TEST_ASSERT_EQUAL(1, usrsocktest_daemon_get_num_recv_empty_sockets());
+          TEST_ASSERT_EQUAL(1,
+                            usrsocktest_daemon_get_num_connected_sockets());
+          TEST_ASSERT_EQUAL(1,
+                           usrsocktest_daemon_get_num_recv_empty_sockets());
         }
 
       /* Poll for output (no timeout). Close connection. */
@@ -860,7 +889,8 @@ static void Poll2(struct usrsocktest_daemon_conf_s *dconf)
       TEST_ASSERT_EQUAL(0, pfd.revents & POLLOUT);
       TEST_ASSERT_EQUAL(1, usrsocktest_daemon_get_num_active_sockets());
       TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_connected_sockets());
-      TEST_ASSERT_EQUAL(1, usrsocktest_daemon_get_num_remote_disconnected_sockets());
+      TEST_ASSERT_EQUAL(1,
+                 usrsocktest_daemon_get_num_remote_disconnected_sockets());
 
       for (count = 0; count < 2; count++)
         {
@@ -870,8 +900,10 @@ static void Poll2(struct usrsocktest_daemon_conf_s *dconf)
           datalen = sizeof(databuf);
           ret = read(sd, data, datalen);
           TEST_ASSERT_EQUAL(0, ret);
-          TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_connected_sockets());
-          TEST_ASSERT_EQUAL(1, usrsocktest_daemon_get_num_remote_disconnected_sockets());
+          TEST_ASSERT_EQUAL(0,
+                          usrsocktest_daemon_get_num_connected_sockets());
+          TEST_ASSERT_EQUAL(1,
+                  usrsocktest_daemon_get_num_remote_disconnected_sockets());
           TEST_ASSERT_EQUAL(1, usrsocktest_daemon_get_num_active_sockets());
           TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_recv_bytes());
         }
@@ -885,9 +917,11 @@ static void Poll2(struct usrsocktest_daemon_conf_s *dconf)
           ret = write(sd, data, datalen);
           TEST_ASSERT_EQUAL(-1, ret);
           TEST_ASSERT_EQUAL(EPIPE, errno);
-          TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_connected_sockets());
+          TEST_ASSERT_EQUAL(0,
+                          usrsocktest_daemon_get_num_connected_sockets());
           TEST_ASSERT_EQUAL(1, usrsocktest_daemon_get_num_active_sockets());
-          TEST_ASSERT_EQUAL(1, usrsocktest_daemon_get_num_remote_disconnected_sockets());
+          TEST_ASSERT_EQUAL(1,
+                   usrsocktest_daemon_get_num_remote_disconnected_sockets());
           TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_send_bytes());
         }
 
@@ -913,7 +947,7 @@ static void Poll2(struct usrsocktest_daemon_conf_s *dconf)
 }
 
 /****************************************************************************
- * Name: RemoteDisconnect test group setup
+ * Name: remote_disconnect test group setup
  *
  * Description:
  *   Setup function executed before each testcase in this test group
@@ -929,14 +963,14 @@ static void Poll2(struct usrsocktest_daemon_conf_s *dconf)
  *
  ****************************************************************************/
 
-TEST_SETUP(RemoteDisconnect)
+TEST_SETUP(remote_disconnect)
 {
   sd = -1;
   started = false;
 }
 
 /****************************************************************************
- * Name: RemoteDisconnect test group teardown
+ * Name: remote_disconnect test group teardown
  *
  * Description:
  *   Setup function executed after each testcase in this test group
@@ -952,14 +986,16 @@ TEST_SETUP(RemoteDisconnect)
  *
  ****************************************************************************/
 
-TEST_TEAR_DOWN(RemoteDisconnect)
+TEST_TEAR_DOWN(remote_disconnect)
 {
   int ret;
+
   if (sd >= 0)
     {
       ret = close(sd);
       assert(ret >= 0);
     }
+
   if (started)
     {
       ret = usrsocktest_daemon_stop();
@@ -967,115 +1003,115 @@ TEST_TEAR_DOWN(RemoteDisconnect)
     }
 }
 
-TEST(RemoteDisconnect, Unreachable)
+TEST(remote_disconnect, unreachable)
 {
   usrsocktest_daemon_config = usrsocktest_daemon_defconf;
-  Unreachable(&usrsocktest_daemon_config);
+  unreachable(&usrsocktest_daemon_config);
 }
 
-TEST(RemoteDisconnect, UnreachableDelay)
+TEST(remote_disconnect, unreachable_delay)
 {
   usrsocktest_daemon_config = usrsocktest_daemon_defconf;
   usrsocktest_daemon_config.delay_all_responses = true;
-  Unreachable(&usrsocktest_daemon_config);
+  unreachable(&usrsocktest_daemon_config);
 }
 
-TEST(RemoteDisconnect, Send)
+TEST(remote_disconnect, remote_disconnect_send)
 {
   usrsocktest_daemon_config = usrsocktest_daemon_defconf;
-  Send(&usrsocktest_daemon_config);
+  remote_disconnect_send(&usrsocktest_daemon_config);
 }
 
-TEST(RemoteDisconnect, SendDelay)
+TEST(remote_disconnect, remote_disconnect_send_delay)
 {
   usrsocktest_daemon_config = usrsocktest_daemon_defconf;
   usrsocktest_daemon_config.delay_all_responses = true;
-  Send(&usrsocktest_daemon_config);
+  remote_disconnect_send(&usrsocktest_daemon_config);
 }
 
-TEST(RemoteDisconnect, Send2)
+TEST(remote_disconnect, remote_disconnect_send2)
 {
   usrsocktest_daemon_config = usrsocktest_daemon_defconf;
-  Send2(&usrsocktest_daemon_config);
+  remote_disconnect_send2(&usrsocktest_daemon_config);
 }
 
-TEST(RemoteDisconnect, Send2Delay)
+TEST(remote_disconnect, remote_disconnect_send2_delay)
 {
   usrsocktest_daemon_config = usrsocktest_daemon_defconf;
   usrsocktest_daemon_config.delay_all_responses = true;
-  Send2(&usrsocktest_daemon_config);
+  remote_disconnect_send2(&usrsocktest_daemon_config);
 }
 
-TEST(RemoteDisconnect, Receive)
+TEST(remote_disconnect, receive)
 {
   usrsocktest_daemon_config = usrsocktest_daemon_defconf;
-  Receive(&usrsocktest_daemon_config);
+  receive(&usrsocktest_daemon_config);
 }
 
-TEST(RemoteDisconnect, ReceiveDelay)
+TEST(remote_disconnect, receive_delay)
 {
   usrsocktest_daemon_config = usrsocktest_daemon_defconf;
   usrsocktest_daemon_config.delay_all_responses = true;
-  Receive(&usrsocktest_daemon_config);
+  receive(&usrsocktest_daemon_config);
 }
 
-TEST(RemoteDisconnect, Receive2)
+TEST(remote_disconnect, receive2)
 {
   usrsocktest_daemon_config = usrsocktest_daemon_defconf;
-  Receive2(&usrsocktest_daemon_config);
+  receive2(&usrsocktest_daemon_config);
 }
 
-TEST(RemoteDisconnect, Receive2Delay)
+TEST(remote_disconnect, receive2_delay)
 {
   usrsocktest_daemon_config = usrsocktest_daemon_defconf;
   usrsocktest_daemon_config.delay_all_responses = true;
-  Receive2(&usrsocktest_daemon_config);
+  receive2(&usrsocktest_daemon_config);
 }
 
-TEST(RemoteDisconnect, Poll)
+TEST(remote_disconnect, remote_disconnect_poll)
 {
   usrsocktest_daemon_config = usrsocktest_daemon_defconf;
-  Poll(&usrsocktest_daemon_config);
+  remote_disconnect_poll(&usrsocktest_daemon_config);
 }
 
-TEST(RemoteDisconnect, PollDelay)
+TEST(remote_disconnect, remote_disconnect_poll_delay)
 {
   usrsocktest_daemon_config = usrsocktest_daemon_defconf;
   usrsocktest_daemon_config.delay_all_responses = true;
-  Poll(&usrsocktest_daemon_config);
+  remote_disconnect_poll(&usrsocktest_daemon_config);
 }
 
-TEST(RemoteDisconnect, Poll2)
+TEST(remote_disconnect, remote_disconnect_poll2)
 {
   usrsocktest_daemon_config = usrsocktest_daemon_defconf;
-  Poll2(&usrsocktest_daemon_config);
+  remote_disconnect_poll2(&usrsocktest_daemon_config);
 }
 
-TEST(RemoteDisconnect, Poll2Delay)
+TEST(remote_disconnect, remote_disconnect_poll2_delay)
 {
   usrsocktest_daemon_config = usrsocktest_daemon_defconf;
   usrsocktest_daemon_config.delay_all_responses = true;
-  Poll2(&usrsocktest_daemon_config);
+  remote_disconnect_poll2(&usrsocktest_daemon_config);
 }
 
 /****************************************************************************
  * Public Functions
  ****************************************************************************/
 
-TEST_GROUP(RemoteDisconnect)
+TEST_GROUP(remote_disconnect)
 {
-  RUN_TEST_CASE(RemoteDisconnect, Unreachable);
-  RUN_TEST_CASE(RemoteDisconnect, UnreachableDelay);
-  RUN_TEST_CASE(RemoteDisconnect, Send);
-  RUN_TEST_CASE(RemoteDisconnect, SendDelay);
-  RUN_TEST_CASE(RemoteDisconnect, Send2);
-  RUN_TEST_CASE(RemoteDisconnect, Send2Delay);
-  RUN_TEST_CASE(RemoteDisconnect, Receive);
-  RUN_TEST_CASE(RemoteDisconnect, ReceiveDelay);
-  RUN_TEST_CASE(RemoteDisconnect, Receive2);
-  RUN_TEST_CASE(RemoteDisconnect, Receive2Delay);
-  RUN_TEST_CASE(RemoteDisconnect, Poll);
-  RUN_TEST_CASE(RemoteDisconnect, PollDelay);
-  RUN_TEST_CASE(RemoteDisconnect, Poll2);
-  RUN_TEST_CASE(RemoteDisconnect, Poll2Delay);
+  RUN_TEST_CASE(remote_disconnect, unreachable);
+  RUN_TEST_CASE(remote_disconnect, unreachable_delay);
+  RUN_TEST_CASE(remote_disconnect, remote_disconnect_send);
+  RUN_TEST_CASE(remote_disconnect, remote_disconnect_send_delay);
+  RUN_TEST_CASE(remote_disconnect, remote_disconnect_send2);
+  RUN_TEST_CASE(remote_disconnect, remote_disconnect_send2_delay);
+  RUN_TEST_CASE(remote_disconnect, receive);
+  RUN_TEST_CASE(remote_disconnect, receive_delay);
+  RUN_TEST_CASE(remote_disconnect, receive2);
+  RUN_TEST_CASE(remote_disconnect, receive2_delay);
+  RUN_TEST_CASE(remote_disconnect, remote_disconnect_poll);
+  RUN_TEST_CASE(remote_disconnect, remote_disconnect_poll_delay);
+  RUN_TEST_CASE(remote_disconnect, remote_disconnect_poll2);
+  RUN_TEST_CASE(remote_disconnect, remote_disconnect_poll2_delay);
 }
