@@ -1,5 +1,5 @@
 /****************************************************************************
- * apps/graphics/littlevgl/lv_conf.h
+ * apps/graphics/lvgl/lv_conf.h
  *
  *   Copyright (C) 2018 Gregory Nutt. All rights reserved.
  *   Author: Gábor Kiss-Vámosi <kisvegabor@gmail.com>
@@ -149,7 +149,7 @@ typedef int16_t lv_coord_t;
  * `lv_mem_alloc` and `lv_mem_free`
  */
 
-#define LV_MEM_CUSTOM      0
+#define LV_MEM_CUSTOM      1
 #if LV_MEM_CUSTOM == 0
 
 /* Size of the memory used by `lv_mem_alloc` in bytes (>= 2kB) */
@@ -330,7 +330,11 @@ typedef void * lv_fs_drv_user_data_t;
 
 /* 1: Show CPU usage and FPS count in the right bottom corner */
 
-#define LV_USE_PERF_MONITOR     0
+#ifdef CONFIG_LV_USE_PERF_MONITOR
+#define LV_USE_PERF_MONITOR        CONFIG_LV_USE_PERF_MONITOR
+#else
+#define LV_USE_PERF_MONITOR        0
+#endif
 
 /* 1: Use the functions and types from the older API if possible */
 
@@ -423,10 +427,10 @@ typedef void * lv_img_decoder_user_data_t;
  * It removes the need to manually update the tick with `lv_tick_inc`)
  */
 
-#define LV_TICK_CUSTOM     0
+#define LV_TICK_CUSTOM     1
 #if LV_TICK_CUSTOM == 1
-#define LV_TICK_CUSTOM_INCLUDE  "something.h"       /* Header for the sys time function */
-#define LV_TICK_CUSTOM_SYS_TIME_EXPR (millis())     /* Expression evaluating to current systime in ms */
+#define LV_TICK_CUSTOM_INCLUDE  "lv_tick_interface.h"       /* Header for the sys time function */
+#define LV_TICK_CUSTOM_SYS_TIME_EXPR (lv_tick_interface())  /* Expression evaluating to current systime in ms */
 #endif   /* LV_TICK_CUSTOM */
 
 typedef void * lv_disp_drv_user_data_t;             /* Type of user data in the display driver */
@@ -753,7 +757,7 @@ typedef void * lv_font_user_data_t;
 
 /* Change the built in (v)snprintf functions */
 
-#define LV_SPRINTF_CUSTOM   0
+#define LV_SPRINTF_CUSTOM   1
 #if LV_SPRINTF_CUSTOM
 #  define LV_SPRINTF_INCLUDE <stdio.h>
 #  define lv_snprintf     snprintf
