@@ -1,35 +1,20 @@
 /****************************************************************************
  * apps/netutils/ftpc/ftpc_getfile.c
  *
- *   Copyright (C) 2011 Gregory Nutt. All rights reserved.
- *   Author: Gregory Nutt <gnutt@nuttx.org>
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.  The
+ * ASF licenses this file to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance with the
+ * License.  You may obtain a copy of the License at
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- * 3. Neither the name NuttX nor the names of its contributors may be
- *    used to endorse or promote products derived from this software
- *    without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
- * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
- * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
- * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
- * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
- * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
- * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+ * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
+ * License for the specific language governing permissions and limitations
+ * under the License.
  *
  ****************************************************************************/
 
@@ -43,6 +28,7 @@
 #include <stdlib.h>
 #include <unistd.h>
 #include <string.h>
+#include <assert.h>
 #include <debug.h>
 #include <errno.h>
 
@@ -269,6 +255,8 @@ int ftpc_getfile(SESSION handle, FAR const char *rname,
       goto errout;
     }
 
+  offset = 0;
+
   /* Get information about the local file */
 
   ret = stat(abslpath, &statbuf);
@@ -281,29 +269,25 @@ int ftpc_getfile(SESSION handle, FAR const char *rname,
           nwarn("WARNING: '%s' is a directory\n", abslpath);
           goto errout_with_abspath;
         }
-    }
 
-  /* Is it write-able? */
+      /* Is it write-able? */
 
 #ifdef S_IWRITE
-  if (!(statbuf.st_mode & S_IWRITE))
-    {
-      nwarn("WARNING: '%s' permission denied\n", abslpath);
-      goto errout_with_abspath;
-    }
+      if (!(statbuf.st_mode & S_IWRITE))
+        {
+          nwarn("WARNING: '%s' permission denied\n", abslpath);
+          goto errout_with_abspath;
+        }
 #endif
 
-  /* Are we resuming the transfers?  Is so then the starting offset is the
-   * size of the existing, partial file.
-   */
+      /* Are we resuming the transfers?  Is so then the starting offset is
+       * the size of the existing, partial file.
+       */
 
-  if (how == FTPC_GET_RESUME)
-    {
-      offset = statbuf.st_size;
-    }
-  else
-    {
-      offset = 0;
+      if (how == FTPC_GET_RESUME)
+        {
+          offset = statbuf.st_size;
+        }
     }
 
   /* Setup to receive the file */
