@@ -1,35 +1,20 @@
 /****************************************************************************
- * apps/nshlib/dbg_timcmds.c
+ * apps/nshlib/nsh_timcmds.c
  *
- *   Copyright (C) 2011-2012, 2014, 2019 Gregory Nutt. All rights reserved.
- *   Author: Gregory Nutt <gnutt@nuttx.org>
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.  The
+ * ASF licenses this file to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance with the
+ * License.  You may obtain a copy of the License at
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- * 3. Neither the name NuttX nor the names of its contributors may be
- *    used to endorse or promote products derived from this software
- *    without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
- * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
- * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
- * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
- * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
- * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
- * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+ * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
+ * License for the specific language governing permissions and limitations
+ * under the License.
  *
  ****************************************************************************/
 
@@ -110,7 +95,7 @@ static inline int date_month(FAR const char *abbrev)
 
 #ifndef CONFIG_NSH_DISABLE_DATE
 static inline int date_showtime(FAR struct nsh_vtbl_s *vtbl,
-                                FAR const char *name)
+                                FAR const char *name, bool utc)
 {
   static const char format[] = "%a, %b %d %H:%M:%S %Y";
   struct timespec ts;
@@ -129,10 +114,21 @@ static inline int date_showtime(FAR struct nsh_vtbl_s *vtbl,
 
   /* Break the current time up into the format needed by strftime */
 
-  if (gmtime_r((FAR const time_t *)&ts.tv_sec, &tm) == NULL)
+  if (utc)
     {
-      nsh_error(vtbl, g_fmtcmdfailed, name, "gmtime_r", NSH_ERRNO);
-      return ERROR;
+      if (gmtime_r((FAR const time_t *)&ts.tv_sec, &tm) == NULL)
+        {
+          nsh_error(vtbl, g_fmtcmdfailed, name, "gmtime_r", NSH_ERRNO);
+          return ERROR;
+        }
+    }
+  else
+    {
+      if (localtime_r((FAR const time_t *)&ts.tv_sec, &tm) == NULL)
+        {
+          nsh_error(vtbl, g_fmtcmdfailed, name, "localtime_r", NSH_ERRNO);
+          return ERROR;
+        }
     }
 
   /* Show the current time in the requested format */
@@ -155,7 +151,8 @@ static inline int date_showtime(FAR struct nsh_vtbl_s *vtbl,
 
 #ifndef CONFIG_NSH_DISABLE_DATE
 static inline int date_settime(FAR struct nsh_vtbl_s *vtbl,
-                               FAR const char *name, FAR char *newtime)
+                               FAR const char *name, bool utc,
+                               FAR char *newtime)
 {
   struct timespec ts;
   struct tm tm;
@@ -266,7 +263,7 @@ static inline int date_settime(FAR struct nsh_vtbl_s *vtbl,
 
   /* Convert this to the right form, then set the timer */
 
-  ts.tv_sec  = mktime(&tm);
+  ts.tv_sec  = utc ? timegm(&tm): mktime(&tm);
   ts.tv_nsec = 0;
 
   ret = clock_settime(CLOCK_REALTIME, &ts);
@@ -376,12 +373,13 @@ int cmd_date(FAR struct nsh_vtbl_s *vtbl, int argc, char **argv)
 {
   FAR char *newtime = NULL;
   FAR const char *errfmt;
+  bool utc = false;
   int option;
   int ret;
 
   /* Get the date options:  date [-s time] [+FORMAT] */
 
-  while ((option = getopt(argc, argv, "s:")) != ERROR)
+  while ((option = getopt(argc, argv, "s:u")) != ERROR)
     {
       if (option == 's')
         {
@@ -389,6 +387,12 @@ int cmd_date(FAR struct nsh_vtbl_s *vtbl, int argc, char **argv)
 
           newtime = optarg;
         }
+      else if (option == 'u')
+        {
+          /* We will use the UTC time */
+
+          utc = true;
+        }
       else /* option = '?' */
         {
           errfmt = g_fmtarginvalid;
@@ -410,11 +414,11 @@ int cmd_date(FAR struct nsh_vtbl_s *vtbl, int argc, char **argv)
 
   if (newtime)
     {
-      ret = date_settime(vtbl, argv[0], newtime);
+      ret = date_settime(vtbl, argv[0], utc, newtime);
     }
   else
     {
-      ret = date_showtime(vtbl, argv[0]);
+      ret = date_showtime(vtbl, argv[0], utc);
     }
 
   return ret;
