@@ -102,7 +102,8 @@ struct fstest_filedesc_s
 
 static uint8_t g_fileimage[CONFIG_TESTING_FSTEST_MAXFILE];
 static struct fstest_filedesc_s g_files[CONFIG_TESTING_FSTEST_MAXOPEN];
-static const char g_mountdir[] = CONFIG_TESTING_FSTEST_MOUNTPT "/";
+static char g_mountdir[CONFIG_TESTING_FSTEST_MAXNAME] =
+            CONFIG_TESTING_FSTEST_MOUNTPT "/";
 static int g_nfiles;
 static int g_ndeleted;
 static int g_nfailed;
@@ -411,7 +412,7 @@ static inline int fstest_wrfile(FAR struct fstest_filedesc_s *file)
   fstest_randname(file);
   fstest_randfile(file);
 
-  fd = open(file->name, O_WRONLY | O_CREAT | O_EXCL, 0666);
+  fd = open(file->name, O_WRONLY | O_CREAT | O_EXCL | O_TRUNC, 0666);
   if (fd < 0)
     {
       /* If it failed because there is no space on the device, then don't
@@ -925,14 +926,14 @@ static int fstest_directory(void)
 
   /* Open the directory */
 
-  dirp = opendir(CONFIG_TESTING_FSTEST_MOUNTPT);
+  dirp = opendir(g_mountdir);
 
   if (!dirp)
     {
       /* Failed to open the directory */
 
       printf("ERROR: Failed to open directory '%s': %d\n",
-             CONFIG_TESTING_FSTEST_MOUNTPT, errno);
+             g_mountdir, errno);
       return ERROR;
     }
 
@@ -959,6 +960,19 @@ static int fstest_directory(void)
   return OK;
 }
 
+/****************************************************************************
+ * Show help Message
+ ****************************************************************************/
+
+static void show_useage(void)
+{
+  printf("Usage : fstest [OPTION [ARG]] ...\n");
+  printf("-h    show this help statement\n");
+  printf("-n    num of test loop e.g. [%d]\n", CONFIG_TESTING_FSTEST_NLOOPS);
+  printf("-m    mount point tobe test e.g. [%s]\n",
+          CONFIG_TESTING_FSTEST_MOUNTPT);
+}
+
 /****************************************************************************
  * Public Functions
  ****************************************************************************/
@@ -972,10 +986,43 @@ int main(int argc, FAR char *argv[])
   struct statfs buf;
   unsigned int i;
   int ret;
+  int loop_num;
+  int option;
 
   /* Seed the random number generated */
 
   srand(0x93846);
+  loop_num = CONFIG_TESTING_FSTEST_NLOOPS;
+  strcpy(g_mountdir, CONFIG_TESTING_FSTEST_MOUNTPT);
+
+  /* Opt Parse */
+
+  while ((option = getopt(argc, argv, ":m:hn:")) != -1)
+    {
+      switch (option)
+        {
+          case 'm':
+            strcpy(g_mountdir, optarg);
+            break;
+          case 'h':
+            show_useage();
+            exit(0);
+          case 'n':
+            loop_num = atoi(optarg);
+            break;
+          case ':':
+            printf("Error: Missing required argument\n");
+            exit(1);
+          case '?':
+            printf("Error: Unrecognized option\n");
+            exit(1);
+        }
+    }
+
+  if (g_mountdir[strlen(g_mountdir)-1] != '/')
+    {
+      strcat(g_mountdir, "/");
+    }
 
   /* Set up memory monitoring */
 
@@ -990,7 +1037,7 @@ int main(int argc, FAR char *argv[])
 #if CONFIG_TESTING_FSTEST_NLOOPS == 0
   for (i = 0; ; i++)
 #else
-  for (i = 1; i <= CONFIG_TESTING_FSTEST_NLOOPS; i++)
+  for (i = 1; i <= loop_num; i++)
 #endif
     {
       /* Write a files to the file system until either (1) all of the open
@@ -1021,6 +1068,7 @@ int main(int argc, FAR char *argv[])
           printf("ERROR: Failed to verify files\n");
           printf("  Number of files: %d\n", g_nfiles);
           printf("  Number deleted:  %d\n", g_ndeleted);
+          exit(ret);
         }
       else
         {
@@ -1040,6 +1088,7 @@ int main(int argc, FAR char *argv[])
           printf("ERROR: Failed to delete files\n");
           printf("  Number of files: %d\n", g_nfiles);
           printf("  Number deleted:  %d\n", g_ndeleted);
+          exit(ret);
         }
       else
         {
@@ -1065,6 +1114,7 @@ int main(int argc, FAR char *argv[])
           printf("ERROR: Failed to verify files\n");
           printf("  Number of files: %d\n", g_nfiles);
           printf("  Number deleted:  %d\n", g_ndeleted);
+          exit(ret);
         }
       else
         {
@@ -1081,6 +1131,7 @@ int main(int argc, FAR char *argv[])
       if (ret < 0)
         {
            printf("ERROR: statfs failed: %d\n", errno);
+           exit(ret);
         }
       else
         {
